bootstrap.BootstrapDocument

|  | ## Cheshire3 Object Model: Class BootstrapDocument

Module bootstrap :: Class BootstrapDocument

## Class BootstrapDocument
source code

Instance Methods

__init__(self, fileHandle)
get_raw(self)

Class Variables

handle |
txt |

Method Details

### __init__(self, fileHandle) (Constructor) | source code

### get_raw(self) | source code

Class Variable Details

    ### handle Value:
        None

    ### txt Value:
        ''